@@ -6,8 +6,6 @@ import random
 import platform
 from uuid import getnode as get_mac
 
-from allo.model.config import AlloConfig
-
 TELEPORT_SHA = "786e399511525889778d2a3e64bc5d18f7ecddf6eaac684c224249657f404b76" \
     if os.getenv("ALLOENV") == "TEST" \
     else "fa04922fca037e9f2f6ff0c770ab10c746843c91b4aad8008df24d8b79b6b206"
@@ -31,6 +29,7 @@ CODEPRODUIT = {
 
 
 def getnode():
+    from .model.config import AlloConfig
     config = AlloConfig.load()
     if hasattr(config, "id_client"):
         return config.id_client
